@@ -1,5 +1,6 @@
 from .karate import KarateClub
 from .tu_dataset import TUDataset
+from .gnn_benchmark_dataset import GNNBenchmarkDataset
 from .planetoid import Planetoid
 from .citation_full import CitationFull, CoraFull
 from .coauthor import Coauthor
@@ -10,6 +11,8 @@ from .flickr import Flickr
 from .yelp import Yelp
 from .qm7 import QM7b
 from .qm9 import QM9
+from .zinc import ZINC
+from .molecule_net import MoleculeNet
 from .entities import Entities
 from .ged_dataset import GEDDataset
 from .mnist_superpixels import MNISTSuperpixels
@@ -34,10 +37,12 @@ from .snap_dataset import SNAPDataset
 from .suite_sparse import SuiteSparseMatrixCollection
 from .particle import TrackMLParticleTrackingDataset
 from .aminer import AMiner
+from .word_net import WordNet18
 
 __all__ = [
     'KarateClub',
     'TUDataset',
+    'GNNBenchmarkDataset',
     'Planetoid',
     'CitationFull',
     'CoraFull',
@@ -49,6 +54,8 @@ __all__ = [
     'Yelp',
     'QM7b',
     'QM9',
+    'ZINC',
+    'MoleculeNet',
     'Entities',
     'GEDDataset',
     'MNISTSuperpixels',
@@ -73,4 +80,5 @@ __all__ = [
     'SuiteSparseMatrixCollection',
     'TrackMLParticleTrackingDataset',
     'AMiner',
+    'WordNet18',
 ]
