@@ -13,7 +13,7 @@ from .arma_conv import ARMAConv
 from .sg_conv import SGConv
 from .appnp import APPNP
 from .mf_conv import MFConv
-from .rgcn_conv import RGCNConv
+from .rgcn_conv import RGCNConv, FastRGCNConv
 from .signed_conv import SignedConv
 from .dna_conv import DNAConv
 from .point_conv import PointConv
@@ -27,6 +27,8 @@ from .ppf_conv import PPFConv
 from .feast_conv import FeaStConv
 from .hypergraph_conv import HypergraphConv
 from .le_conv import LEConv
+from .pna_conv import PNAConv
+from .cluster_gcn_conv import ClusterGCNConv
 
 __all__ = [
     'MessagePassing',
@@ -46,6 +48,7 @@ __all__ = [
     'APPNP',
     'MFConv',
     'RGCNConv',
+    'FastRGCNConv',
     'SignedConv',
     'DNAConv',
     'PointConv',
@@ -61,4 +64,6 @@ __all__ = [
     'FeaStConv',
     'HypergraphConv',
     'LEConv',
+    'PNAConv',
+    'ClusterGCNConv',
 ]
